==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN encendido</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN apagado</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Bloq Mayús activado</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Bloq Mayús desactivado</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico activado</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desactivado</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Panel táctil activado.</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Panel táctil desactivado.</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Alternar panel táctil</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Alternar Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Modo avión activado</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Modo avión desactivado.</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Energía equilibrada</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Ahorro de energía</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Alto rendimiento</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efectos de ventana activados</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efectos de ventana desactivados</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Error al activar efectos de ventana</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Micrófono apagado</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Micrófono encendido</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN encendido</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN apagado</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Bloq Mayús activado</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Bloq Mayús desactivado</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico activado</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desactivado</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Panel táctil activado.</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Panel táctil desactivado.</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Alternar panel táctil</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Alternar Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Modo avión activado</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Modo avión desactivado.</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Energía equilibrada</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Ahorro de energía</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Alto rendimiento</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efectos de ventana activados</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efectos de ventana desactivados</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Error al activar efectos de ventana</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Micrófono apagado</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Micrófono encendido</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
